==> portmanager-0.3.4.tar.gz: portmanager-0.3.4/libMGPM/src/MGPMrBestOldPort.c <==
/*
	Copyright (C) 2005  Michael C. Shultz

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions
	are met:

	1. Redistributions of source code must retain the above copyright
	   notice, this list of conditions and the following disclaimer.
	2. Redistributions in binary form must reproduce the above copyright
	   notice, this list of conditions and the following disclaimer in the
	   documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
	IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
	OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
	IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
	NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
	DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
	THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
	THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

	Michael C. Shultz
	ringworm01@gmail.com
	Box 3238 Landers, CA 92285
*/

/*
*/
#include	<libMGPM.h>

int	MGPMrBestOldPort( structProperty* property, char* oldPortDir, char* oldPortName )
{
	char	exact[]					= "exact";
	char	id[]					= "MGPMrBestOldPort";
	char*	availableDependenciesDbDependencyDirPtr	= NULL;
	char*	oldPortDirPtr				= NULL;
	char*	oldPortNamePtr				= NULL;
	char*	reasonPtr				= NULL;
	int	oldPortsDbIDX				= 0;
	int	oldPortsDbQTX				= 0;
	int	skip					= 0;

	property->availableDependenciesDb	= MGdbOpen( property->availableDependenciesDbFileName );
	property->oldPortsDb			= MGdbOpen( property->oldPortsDbFileName );
	property->ignoreDb			= MGdbOpen( property->ignoreDbFileName );

	oldPortsDbIDX				= 1;
	oldPortsDbQTX				= MGdbGetRecordQty( property->oldPortsDb );
	skip					= 0;
	while( oldPortsDbIDX < oldPortsDbQTX )
	{
		/*
		 * get portDir entry from oldPortsDb
		 */
		skip	= 0;
		oldPortDirPtr	= MGdbGet( property->oldPortsDb, oldPortsDbIDX, property->fieldOldPortsDbOldPortDir );
		oldPortNamePtr	= MGdbGet( property->oldPortsDb, oldPortsDbIDX, property->fieldOldPortsDbOldPortName );

		if( oldPortDirPtr )
		{
			strcpy( oldPortDir, oldPortDirPtr );
			if( oldPortNamePtr )
			{
				strcpy( oldPortName, oldPortNamePtr );
			}
		}
		else
		{
			fprintf( stdout, "%s %s error: No directory in oldPortsDb at record %d\n", id, PACKAGE_VERSION, oldPortsDbIDX );
			while( fflush( stdout ) );
			if( property->pmMode == 0 )
			{
				MGdbDestroy( property->dependencyPortsDb );
			}
			else
			{
				MGdbDestroy( property->availableDependenciesDb );
			}
			MGdbDestroy( property->oldPortsDb );
			MGdbDestroy( property->ignoreDb );
			return( 1 );
		}

		MGdbGoTop( property->ignoreDb );
		if( ( reasonPtr = MGdbSeek( property->ignoreDb, property->fieldignoreDbPortDir, oldPortDirPtr, property->fieldIgnoreDbReason, exact ) ) )
		{
			fprintf( stdout, "skipping %s %s marked IGNORE reason: %s\n", oldPortNamePtr, oldPortDirPtr, reasonPtr );
			while( fflush( stdout ) );
			oldPortsDbIDX++;
			skip	= 100;
			continue;
		}

		/*
		 * find oldPortDir's dependencies in availableDependenciesDb
		 */
		MGdbGoTop( property->availableDependenciesDb );

		if( strcmp( oldPortDir, "/java" ) == 0 )
		{
			while( ( availableDependenciesDbDependencyDirPtr = MGdbSeek( property->availableDependenciesDb,
										property->fieldAvailableDependenciesDbPortDir,
										oldPortDir,
										property->fieldAvailableDependenciesDbDependencyDir,
										exact ) ) &&
									strcmp( "BUILD_DEPENDS",
										MGdbGet( property->availableDependenciesDb,
											MGdbGetRecno( property->availableDependenciesDb ) - 1,
											property->fieldAvailableDependenciesDbDependType ) ) )
			{
				/*
				 * Ensure oldPortDir does not have a dependency in oldPortsDb before updating it
				 */
				MGdbGoTop( property->oldPortsDb );
				if( MGdbSeek( property->oldPortsDb,
					property->fieldOldPortsDbOldPortDir,
					availableDependenciesDbDependencyDirPtr,
					property->fieldOldPortsDbOldPortDir,
					exact ) )
				{
					fprintf( stdout, "skipping %s %s until dependency %s updated\n",
						oldPortName,
						oldPortDir,
						MGdbGet( property->availableDependenciesDb,
							MGdbGetRecno( property->availableDependenciesDb ) - 1,
							property->fieldAvailableDependenciesDbDependencyName ) );
					while( fflush( stdout ) );
					skip	= 100;
					break;
				}
			}				
			if( skip == 100 )
			{
				oldPortsDbIDX++;
				continue;
			}
		}
		else
		{
			while( ( availableDependenciesDbDependencyDirPtr = MGdbSeek( property->availableDependenciesDb,
								property->fieldAvailableDependenciesDbPortDir,
								oldPortDir,
								property->fieldAvailableDependenciesDbDependencyDir,
								exact ) ) )
			{
				/*
				 * Ensure oldPortDir does not have a dependency in oldPortsDb before updating it
				 */
				MGdbGoTop( property->oldPortsDb );
				if( MGdbSeek( property->oldPortsDb,
					property->fieldOldPortsDbOldPortDir,
					availableDependenciesDbDependencyDirPtr,
					property->fieldOldPortsDbOldPortDir,
					exact ) )
				{
					fprintf( stdout, "skipping %s %s until dependency %s updated\n",
						oldPortName,
						oldPortDir,
						MGdbGet( property->availableDependenciesDb,
							MGdbGetRecno( property->availableDependenciesDb ) - 1,
							property->fieldAvailableDependenciesDbDependencyName ) );
					while( fflush( stdout ) );
					skip	= 100;
					break;
				}
			}				
			if( skip == 100 )
			{
				oldPortsDbIDX++;
				continue;
			}
		}
		if( availableDependenciesDbDependencyDirPtr == NULL )
		{
			/*
			 * oldPortDir has no dependencies so safe to update 
			 */
			skip	= 0;				
			break;
		}
		oldPortsDbIDX++;
	}

	MGdbDestroy( property->availableDependenciesDb );
	MGdbDestroy( property->ignoreDb );
	MGdbDestroy( property->oldPortsDb );
	if( oldPortsDbIDX >= oldPortsDbQTX )
	{
		/*
		 * If skip=100 means all ports can't be updated 
		 * If skip = 0 means all ports were updated and
		 * oldPortDir should be NULL ie oldPortDir[0] == 0
		 */
/*
fprintf( stdout, "%s debug 01: oldPortName-=>%s oldPortDir-=>%s skip-=>%d\n", id, oldPortName, oldPortDir, skip );
while( fflush( stdout ) );
*/
		return( skip );
	}
	/*
	 * If here a port is ready to be updated and there are still more to concider
	 * oldPortDir should not be NULL ie strlen( oldPortDir ) > 0
	 */
/*
fprintf( stdout, "%s debug 02: oldPortName-=>%s oldPortDir-=>%s\n", id, oldPortName, oldPortDir );
while( fflush( stdout ) );
*/
	return( 0 );
}

==> portmanager-0.4.1.tar.gz: portmanager-0.4.1/libMGPM/src/MGPMrBestOldPort.c <==
/*
	Copyright (C) 2005  Michael C. Shultz

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions
	are met:

	1. Redistributions of source code must retain the above copyright
	   notice, this list of conditions and the following disclaimer.
	2. Redistributions in binary form must reproduce the above copyright
	   notice, this list of conditions and the following disclaimer in the
	   documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
	IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
	OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
	IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
	NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
	DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
	THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
	THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

	Michael C. Shultz
	ringworm01@gmail.com
	Box 3238 Landers, CA 92285
*/

/*
*/
#include	<libMGPM.h>

int	MGPMrBestOldPort( structProperty* property, char* oldPortDir, char* oldPortName )
{
	char	exact[]					= "exact";
	char	id[]					= "MGPMrBestOldPort";
	char*	availableDependenciesDbDependencyDirPtr	= NULL;
	char*	oldPortDirPtr				= NULL;
	char*	oldPortNamePtr				= NULL;
	char*	reasonPtr				= NULL;
	int	oldPortsDbIDX				= 0;
	int	oldPortsDbQTX				= 0;
	int	skip					= 0;

	property->availableDependenciesDb	= MGdbOpen( property->availableDependenciesDbFileName );
	property->oldPortsDb			= MGdbOpen( property->oldPortsDbFileName );
	property->ignoreDb			= MGdbOpen( property->ignoreDbFileName );

	oldPortsDbIDX				= 1;
	oldPortsDbQTX				= MGdbGetRecordQty( property->oldPortsDb );
	skip					= 0;
	while( oldPortsDbIDX < oldPortsDbQTX )
	{
		/*
		 * get portDir entry from oldPortsDb
		 */
		skip	= 0;
		oldPortDirPtr	= MGdbGet( property->oldPortsDb, oldPortsDbIDX, property->fieldOldPortsDbOldPortDir );
		oldPortNamePtr	= MGdbGet( property->oldPortsDb, oldPortsDbIDX, property->fieldOldPortsDbOldPortName );

		if( oldPortDirPtr )
		{
			MGmStrcpy( oldPortDir, oldPortDirPtr );
			if( oldPortNamePtr )
			{
				MGmStrcpy( oldPortName, oldPortNamePtr );
			}
		}
		else
		{
			fprintf( stdout, "%s %s error: No directory in oldPortsDb at record %d\n", id, PACKAGE_VERSION, oldPortsDbIDX );
			while( fflush( stdout ) );
			if( property->pmMode == 0 )
			{
				MGdbDestroy( property->dependencyPortsDb );
			}
			else
			{
				MGdbDestroy( property->availableDependenciesDb );
			}
			MGdbDestroy( property->oldPortsDb );
			MGdbDestroy( property->ignoreDb );
			return( 1 );
		}

		MGdbGoTop( property->ignoreDb );
		if( ( reasonPtr = MGdbSeek( property->ignoreDb, property->fieldignoreDbPortDir, oldPortDirPtr, property->fieldIgnoreDbReason, exact ) ) )
		{
			fprintf( stdout, "skipping %s %s marked IGNORE reason: %s\n", oldPortNamePtr, oldPortDirPtr, reasonPtr );
			while( fflush( stdout ) );
			oldPortsDbIDX++;
			skip	= 100;
			continue;
		}

		/*
		 * find oldPortDir's dependencies in availableDependenciesDb
		 */
		MGdbGoTop( property->availableDependenciesDb );

		if( strcmp( oldPortDir, "/java" ) == 0 )
		{
			while( ( availableDependenciesDbDependencyDirPtr = MGdbSeek( property->availableDependenciesDb,
										property->fieldAvailableDependenciesDbPortDir,
										oldPortDir,
										property->fieldAvailableDependenciesDbDependencyDir,
										exact ) ) &&
									strcmp( "BUILD_DEPENDS",
										MGdbGet( property->availableDependenciesDb,
											MGdbGetRecno( property->availableDependenciesDb ) - 1,
											property->fieldAvailableDependenciesDbDependType ) ) )
			{
				/*
				 * Ensure oldPortDir does not have a dependency in oldPortsDb before updating it
				 */
				MGdbGoTop( property->oldPortsDb );
				if( MGdbSeek( property->oldPortsDb,
					property->fieldOldPortsDbOldPortDir,
					availableDependenciesDbDependencyDirPtr,
					property->fieldOldPortsDbOldPortDir,
					exact ) )
				{
					fprintf( stdout, "skipping %s %s until dependency %s updated\n",
						oldPortName,
						oldPortDir,
						MGdbGet( property->availableDependenciesDb,
							MGdbGetRecno( property->availableDependenciesDb ) - 1,
							property->fieldAvailableDependenciesDbDependencyName ) );
					while( fflush( stdout ) );
					skip	= 100;
					break;
				}
			}				
			if( skip == 100 )
			{
				oldPortsDbIDX++;
				continue;
			}
		}
		else
		{
			while( ( availableDependenciesDbDependencyDirPtr = MGdbSeek( property->availableDependenciesDb,
								property->fieldAvailableDependenciesDbPortDir,
								oldPortDir,
								property->fieldAvailableDependenciesDbDependencyDir,
								exact ) ) )
			{
/*
fprintf( stdout, "debug(1): availableDependenciesDbDependencyDirPtr-=>%s\n", availableDependenciesDbDependencyDirPtr );
while( fflush( stdout ) );
*/
				/*
				 * Ensure oldPortDir does not have a dependency in oldPortsDb before updating it
				 */
				MGdbGoTop( property->oldPortsDb );
				if( MGdbSeek( property->oldPortsDb,
					property->fieldOldPortsDbOldPortDir,
					availableDependenciesDbDependencyDirPtr,
					property->fieldOldPortsDbOldPortDir,
					exact ) )
				{
					fprintf( stdout, "skipping %s %s until dependency %s updated\n",
						oldPortName,
						oldPortDir,
						MGdbGet( property->availableDependenciesDb,
							MGdbGetRecno( property->availableDependenciesDb ) - 1,
							property->fieldAvailableDependenciesDbDependencyName ) );
					while( fflush( stdout ) );
					skip	= 100;
					break;
				}
			}				
			if( skip == 100 )
			{
				oldPortsDbIDX++;
				continue;
			}
		}
		if( availableDependenciesDbDependencyDirPtr == NULL )
		{
			/*
			 * oldPortDir has no dependencies so safe to update 
			 */
			skip	= 0;				
			break;
		}
		oldPortsDbIDX++;
	}

	MGdbDestroy( property->availableDependenciesDb );
	MGdbDestroy( property->ignoreDb );
	MGdbDestroy( property->oldPortsDb );
	if( oldPortsDbIDX >= oldPortsDbQTX )
	{
		/*
		 * If skip=100 means all ports can't be updated 
		 * If skip = 0 means all ports were updated and
		 * oldPortDir should be NULL ie oldPortDir[0] == 0
		 */
/*
fprintf( stdout, "%s debug 01: oldPortName-=>%s oldPortDir-=>%s skip-=>%d\n", id, oldPortName, oldPortDir, skip );
while( fflush( stdout ) );
*/
		return( skip );
	}
	/*
	 * If here a port is ready to be updated and there are still more to concider
	 * oldPortDir should not be NULL ie strlen( oldPortDir ) > 0
	 */
/*
fprintf( stdout, "%s debug 02: oldPortName-=>%s oldPortDir-=>%s\n", id, oldPortName, oldPortDir );
while( fflush( stdout ) );
*/
	return( 0 );
}
